TxTester

Struct TxTester 

pub struct TxTester {
    pub tx_body: TxBuilderBody,
    pub inputs_evaluating: Vec<TxIn>,
    pub outputs_evaluating: Vec<Output>,
    pub traces: Option<WError>,
}

Fields

tx_body: TxBuilderBodyinputs_evaluating: Vec<TxIn>outputs_evaluating: Vec<Output>traces: Option<WError>

Implementations

Source

impl TxTester

pub fn key_signed(&mut self, key_hash: &str) -> &mut Self

Testing methods for required signers

Checks if a specific key is signed in the transaction.

pub fn one_of_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self

Testing methods for required signers

Checks if any one of the specified keys is signed in the transaction.

pub fn all_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self

Testing methods for required signers

Checks if all specified keys are signed in the transaction.

Source

impl TxTester

pub fn all_inputs(&mut self) -> &mut Self

Filtering methods for testing inputs

Not apply filter to inputs

pub fn inputs_at(&mut self, address: &str) -> &mut Self

Filtering methods for testing inputs

Filter inputs by address

pub fn inputs_with(&mut self, unit: &str) -> &mut Self

Filtering methods for testing inputs

Filter inputs by unit

pub fn inputs_with_policy(&mut self, policy_id: &str) -> &mut Self

Filtering methods for testing inputs

Filter inputs by policy ID

pub fn inputs_at_with_policy( &mut self, address: &str, policy_id: &str, ) -> &mut Self

Filtering methods for testing inputs

Filter inputs by address and policy ID

pub fn inputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self

Filtering methods for testing inputs

Filter inputs by address and unit

pub fn inputs_value(&mut self, expected_value: Value) -> &mut Self

Testing methods for inputs

Reminder - It must be called after filtering methods for inputs

Check if inputs contain the expected value.

pub fn inputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self

Testing methods for inputs

Reminder - It must be called after filtering methods for inputs

Check if inputs contain a specific inline datum.

Source

impl TxTester

pub fn token_minted( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self

Testing methods for mints

Checks if a specific token is minted in the transaction.

pub fn only_token_minted( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self

Testing methods for mints

Checks if a specific token is minted in the transaction and that it is the only mint.

pub fn policy_only_minted_token( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self

Testing methods for mints

Checks if a specific token is minted in the transaction, ensuring that it is the only mint for the given policy ID.

pub fn check_policy_only_burn(&self, policy_id: &str) -> bool

Testing methods for mints

Checks if a specific policy ID is burned in the transaction, ensuring that it is the only minting (i.e. burning item).

pub fn token_minted_logic( &self, policy_id: &str, asset_name: &str, quantity: i128, ) -> bool

Source

impl TxTester

pub fn all_outputs(&mut self) -> &mut Self

Filtering methods for testing outputs

Not apply filter to outputs

pub fn outputs_at(&mut self, address: &str) -> &mut Self

Filtering methods for testing outputs

Filter outputs by address

pub fn outputs_with(&mut self, unit: &str) -> &mut Self

Filtering methods for testing outputs

Filter outputs by unit

pub fn outputs_with_policy(&mut self, policy_id: &str) -> &mut Self

Filtering methods for testing outputs

Filter outputs by policy ID

pub fn outputs_at_with_policy( &mut self, address: &str, policy_id: &str, ) -> &mut Self

Filtering methods for testing outputs

Filter outputs by address and policy ID

pub fn outputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self

Filtering methods for testing outputs

Filter outputs by address and unit

pub fn outputs_value(&mut self, expected_value: Value) -> &mut Self

Testing methods for outputs

Reminder - It must be called after filtering methods for outputs

Check if outputs contain the expected value.

pub fn outputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self

Testing methods for outputs

Reminder - It must be called after filtering methods for outputs

Check if outputs contain a specific inline datum.

Source

impl TxTester

pub fn valid_after(&mut self, required_timestamp: u64) -> &mut Self

Testing methods for validity range

Checks if the transaction is valid after a specified timestamp.

pub fn valid_before(&mut self, required_timestamp: u64) -> &mut Self

Testing methods for validity range

Checks if the transaction is valid before a specified timestamp.

Source

impl TxTester

pub fn new(tx_body: &TxBuilderBody) -> Self

pub fn add_trace(&mut self, func_name: &str, message: &str)

pub fn success(&self) -> bool

pub fn errors(&self) -> String