pub struct TxTester {
pub tx_body: TxBuilderBody,
pub inputs_evaluating: Vec<TxIn>,
pub outputs_evaluating: Vec<Output>,
pub traces: Option<WError>,
}Fields
tx_body: TxBuilderBodyinputs_evaluating: Vec<TxIn>outputs_evaluating: Vec<Output>traces: Option<WError>Implementations
Sourceimpl TxTester
impl TxTester
Sourcepub fn key_signed(&mut self, key_hash: &str) -> &mut Self
pub fn key_signed(&mut self, key_hash: &str) -> &mut Self
Testing methods for required signers
Checks if a specific key is signed in the transaction.
Sourcepub fn one_of_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self
pub fn one_of_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self
Testing methods for required signers
Checks if any one of the specified keys is signed in the transaction.
Sourcepub fn all_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self
pub fn all_keys_signed(&mut self, key_hashes: &[String]) -> &mut Self
Testing methods for required signers
Checks if all specified keys are signed in the transaction.
Sourceimpl TxTester
impl TxTester
Sourcepub fn all_inputs(&mut self) -> &mut Self
pub fn all_inputs(&mut self) -> &mut Self
Filtering methods for testing inputs
Not apply filter to inputs
Sourcepub fn inputs_at(&mut self, address: &str) -> &mut Self
pub fn inputs_at(&mut self, address: &str) -> &mut Self
Filtering methods for testing inputs
Filter inputs by address
Sourcepub fn inputs_with(&mut self, unit: &str) -> &mut Self
pub fn inputs_with(&mut self, unit: &str) -> &mut Self
Filtering methods for testing inputs
Filter inputs by unit
Sourcepub fn inputs_with_policy(&mut self, policy_id: &str) -> &mut Self
pub fn inputs_with_policy(&mut self, policy_id: &str) -> &mut Self
Filtering methods for testing inputs
Filter inputs by policy ID
Sourcepub fn inputs_at_with_policy(
&mut self,
address: &str,
policy_id: &str,
) -> &mut Self
pub fn inputs_at_with_policy( &mut self, address: &str, policy_id: &str, ) -> &mut Self
Filtering methods for testing inputs
Filter inputs by address and policy ID
Sourcepub fn inputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self
pub fn inputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self
Filtering methods for testing inputs
Filter inputs by address and unit
Sourcepub fn inputs_value(&mut self, expected_value: Value) -> &mut Self
pub fn inputs_value(&mut self, expected_value: Value) -> &mut Self
Testing methods for inputs
Reminder - It must be called after filtering methods for inputs
Check if inputs contain the expected value.
Sourcepub fn inputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self
pub fn inputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self
Testing methods for inputs
Reminder - It must be called after filtering methods for inputs
Check if inputs contain a specific inline datum.
Sourceimpl TxTester
impl TxTester
Sourcepub fn token_minted(
&mut self,
policy_id: &str,
asset_name: &str,
quantity: i128,
) -> &mut Self
pub fn token_minted( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self
Testing methods for mints
Checks if a specific token is minted in the transaction.
Sourcepub fn only_token_minted(
&mut self,
policy_id: &str,
asset_name: &str,
quantity: i128,
) -> &mut Self
pub fn only_token_minted( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self
Testing methods for mints
Checks if a specific token is minted in the transaction and that it is the only mint.
Sourcepub fn policy_only_minted_token(
&mut self,
policy_id: &str,
asset_name: &str,
quantity: i128,
) -> &mut Self
pub fn policy_only_minted_token( &mut self, policy_id: &str, asset_name: &str, quantity: i128, ) -> &mut Self
Testing methods for mints
Checks if a specific token is minted in the transaction, ensuring that it is the only mint for the given policy ID.
Sourcepub fn check_policy_only_burn(&self, policy_id: &str) -> bool
pub fn check_policy_only_burn(&self, policy_id: &str) -> bool
Testing methods for mints
Checks if a specific policy ID is burned in the transaction, ensuring that it is the only minting (i.e. burning item).
pub fn token_minted_logic( &self, policy_id: &str, asset_name: &str, quantity: i128, ) -> bool
Sourceimpl TxTester
impl TxTester
Sourcepub fn all_outputs(&mut self) -> &mut Self
pub fn all_outputs(&mut self) -> &mut Self
Filtering methods for testing outputs
Not apply filter to outputs
Sourcepub fn outputs_at(&mut self, address: &str) -> &mut Self
pub fn outputs_at(&mut self, address: &str) -> &mut Self
Filtering methods for testing outputs
Filter outputs by address
Sourcepub fn outputs_with(&mut self, unit: &str) -> &mut Self
pub fn outputs_with(&mut self, unit: &str) -> &mut Self
Filtering methods for testing outputs
Filter outputs by unit
Sourcepub fn outputs_with_policy(&mut self, policy_id: &str) -> &mut Self
pub fn outputs_with_policy(&mut self, policy_id: &str) -> &mut Self
Filtering methods for testing outputs
Filter outputs by policy ID
Sourcepub fn outputs_at_with_policy(
&mut self,
address: &str,
policy_id: &str,
) -> &mut Self
pub fn outputs_at_with_policy( &mut self, address: &str, policy_id: &str, ) -> &mut Self
Filtering methods for testing outputs
Filter outputs by address and policy ID
Sourcepub fn outputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self
pub fn outputs_at_with(&mut self, address: &str, unit: &str) -> &mut Self
Filtering methods for testing outputs
Filter outputs by address and unit
Sourcepub fn outputs_value(&mut self, expected_value: Value) -> &mut Self
pub fn outputs_value(&mut self, expected_value: Value) -> &mut Self
Testing methods for outputs
Reminder - It must be called after filtering methods for outputs
Check if outputs contain the expected value.
Sourcepub fn outputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self
pub fn outputs_inline_datum_exist(&mut self, datum_cbor: &str) -> &mut Self
Testing methods for outputs
Reminder - It must be called after filtering methods for outputs
Check if outputs contain a specific inline datum.
Sourceimpl TxTester
impl TxTester
Sourcepub fn valid_after(&mut self, required_timestamp: u64) -> &mut Self
pub fn valid_after(&mut self, required_timestamp: u64) -> &mut Self
Testing methods for validity range
Checks if the transaction is valid after a specified timestamp.
Sourcepub fn valid_before(&mut self, required_timestamp: u64) -> &mut Self
pub fn valid_before(&mut self, required_timestamp: u64) -> &mut Self
Testing methods for validity range
Checks if the transaction is valid before a specified timestamp.