Function resolve_slot_no
Source pub fn resolve_slot_no(
network: &Network,
milliseconds: Option<u64>,
) -> Option<String>
Resolve the slot number for a network at a given time.
Arguments
network - The Cardano network
milliseconds - Optional POSIX time in milliseconds (defaults to current time)
Returns
The slot number as a string, or None if the network is Custom